==> haskell-network-byte-order-0.1.5-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-byte-order
version:              0.1.5
visibility:           public
id:                   network-byte-order-0.1.5-JMeWBBDuEZfETEAgEqhe3w
key:                  network-byte-order-0.1.5-JMeWBBDuEZfETEAgEqhe3w
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Network byte order utilities
description:          Peek and poke functions for network byte order.
category:             Network
abi:                  a0ffb404549303f0a2a98033e396e8ed
exposed:              True
exposed-modules:      Network.ByteOrder
import-dirs:          /usr/lib/ghc-8.10.1/site-local/network-byte-order-0.1.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/network-byte-order-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/network-byte-order-0.1.5
hs-libraries:         HSnetwork-byte-order-0.1.5-JMeWBBDuEZfETEAgEqhe3w
depends:              base-4.14.0.0 bytestring-0.10.10.0
haddock-interfaces:
    /usr/share/doc/haskell-network-byte-order/html/network-byte-order.haddock

haddock-html:         /usr/share/doc/haskell-network-byte-order/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-byte-order-0.1.5-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-byte-order
version:              0.1.5
visibility:           public
id:                   network-byte-order-0.1.5-KhUdJdleKwlJC2bKact0HR
key:                  network-byte-order-0.1.5-KhUdJdleKwlJC2bKact0HR
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Network byte order utilities
description:          Peek and poke functions for network byte order.
category:             Network
abi:                  d18add9bf5e0a2e553357932b3ce53fe
exposed:              True
exposed-modules:      Network.ByteOrder
import-dirs:          /usr/lib/ghc-8.10.2/site-local/network-byte-order-0.1.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/network-byte-order-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/network-byte-order-0.1.5
hs-libraries:         HSnetwork-byte-order-0.1.5-KhUdJdleKwlJC2bKact0HR
depends:              base-4.14.1.0 bytestring-0.10.10.0
haddock-interfaces:
    /usr/share/doc/haskell-network-byte-order/html/network-byte-order.haddock

haddock-html:         /usr/share/doc/haskell-network-byte-order/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
